@@ -47,7 +47,7 @@ class Mega:
             await self._login_user(email, password)
         else:
             await self.login_anonymous()
-        self._trash_folder_node_id = await self.get_node_by_type(4)[0]
+        self._trash_folder_node_id = (await self.get_node_by_type(4))[0]
         logger.info('Login complete')
         return self
 
@@ -57,7 +57,7 @@ class Mega:
         get_user_salt_resp = await self._api_request({'a': 'us0', 'user': email})
         user_salt = None
         try:
-            user_salt = await base64_to_a32(await get_user_salt_resp['s'])
+            user_salt = await base64_to_a32(get_user_salt_resp['s'])
         except KeyError:
             # v1 user account
             password_aes = await prepare_key(await str_to_a32(password))
@@ -66,11 +66,11 @@ class Mega:
             # v2 user account
             pbkdf2_key = hashlib.pbkdf2_hmac(hash_name='sha512',
                                              password=password.encode(),
-                                             salt=await a32_to_str(user_salt),
+                                             salt=(await a32_to_str(user_salt)),
                                              iterations=100000,
                                              dklen=32)
-            password_aes = await str_to_a32(await pbkdf2_key[:16])
-            user_hash = await base64_url_encode(await pbkdf2_key[-16:])
+            password_aes = await str_to_a32(pbkdf2_key[:16])
+            user_hash = await base64_url_encode(pbkdf2_key[-16:])
         resp = await self._api_request({'a': 'us', 'user': email, 'uh': user_hash})
         if isinstance(resp, int):
             raise RequestError(resp)
@@ -105,7 +105,12 @@ class Mega:
         if 'tsid' in resp:
             tsid = await base64_url_decode(resp['tsid'])
             key_encrypted = await a32_to_str(
-                await encrypt_key(await str_to_a32(tsid[:16]), self.master_key))
+                (
+                  await encrypt_key(
+                      (await str_to_a32(tsid[:16])), self.master_key
+                  )
+                )
+            )
             if key_encrypted == tsid[-16:]:
                 self.sid = resp['tsid']
         elif 'csid' in resp:
@@ -145,7 +150,11 @@ class Mega:
             )
             rsa_decrypter = RSA.construct(rsa_components)
 
-            encrypted_sid = await mpi_to_int(await base64_url_decode(resp['csid']))
+            encrypted_sid = await mpi_to_int(
+                (
+                  await base64_url_decode(resp['csid'])
+                )
+            )
 
             sid = '%x' % rsa_decrypter._decrypt(encrypted_sid)
             sid = binascii.unhexlify('0' + sid if len(sid) % 2 else sid)
@@ -216,12 +225,12 @@ class Mega:
             key = None
             # my objects
             if uid in keys:
-                key = await decrypt_key(await base64_to_a32(keys[uid]), self.master_key)
+                key = await decrypt_key((await base64_to_a32(keys[uid])), self.master_key)
             # shared folders
             elif 'su' in file and 'sk' in file and ':' in file['k']:
-                shared_key = await decrypt_key(await base64_to_a32(file['sk']),
+                shared_key = await decrypt_key((await base64_to_a32(file['sk'])),
                                          self.master_key)
-                key = await decrypt_key(await base64_to_a32(keys[file['h']]), shared_key)
+                key = await decrypt_key((await base64_to_a32(keys[file['h']])), shared_key)
                 if file['su'] not in shared_keys:
                     shared_keys[file['su']] = {}
                 shared_keys[file['su']][file['h']] = shared_key
@@ -231,12 +240,11 @@ class Mega:
                     shared_key = shared_keys[file['u']][hkey]
                     if hkey in keys:
                         key = keys[hkey]
-                        key = await decrypt_key(await base64_to_a32(key), shared_key)
+                        key = await decrypt_key((await base64_to_a32(key)), shared_key)
                         break
             if file['h'] and file['h'] in shared_keys.get('EXP', ()):
                 shared_key = shared_keys['EXP'][file['h']]
-                encrypted_key = await str_to_a32(
-                    await base64_url_decode(file['k'].split(':')[-1]))
+                encrypted_key = await str_to_a32((await base64_url_decode(file['k'].split(':')[-1])))
                 key = await decrypt_key(encrypted_key, shared_key)
                 file['shared_folder_key'] = shared_key
             if key is not None:
@@ -278,7 +286,7 @@ class Mega:
         """
         ok_dict = {}
         for ok_item in files['ok']:
-            shared_key = await decrypt_key(await base64_to_a32(ok_item['k']),
+            shared_key = await decrypt_key((await base64_to_a32(ok_item['k'])),
                                      self.master_key)
             ok_dict[ok_item['h']] = shared_key
         for s_item in files['s']:
@@ -370,7 +378,7 @@ class Mega:
             public_handle = await self._api_request({'a': 'l', 'n': file['h']})
             file_key = file['k'][file['k'].index(':') + 1:]
             decrypted_key = await a32_to_base64(
-                await decrypt_key(await base64_to_a32(file_key), self.master_key))
+                (await decrypt_key((await base64_to_a32(file_key)), self.master_key)))
             return (f'{self.schema}://{self.domain}'
                     f'/#!{public_handle}!{decrypted_key}')
         else:
@@ -524,7 +532,7 @@ class Mega:
         """
         Delete a file by its url
         """
-        path = await self._parse_url(url).split('!')
+        path = (await self._parse_url(url)).split('!')
         public_handle = path[0]
         file_id = await self.get_id_from_public_handle(public_handle)
         return await self.move(file_id, 4)
@@ -543,7 +551,7 @@ class Mega:
         """
         Destroy a file by its url
         """
-        path = await self._parse_url(url).split('!')
+        path = (await self._parse_url(url)).split('!')
         public_handle = path[0]
         file_id = await self.get_id_from_public_handle(public_handle)
         return await self.destroy(file_id)
@@ -597,7 +605,7 @@ class Mega:
             except (RequestError, KeyError):
                 pass
 
-        master_key_cipher = AES.new(await a32_to_str(self.master_key), AES.MODE_ECB)
+        master_key_cipher = AES.new((await a32_to_str(self.master_key)), AES.MODE_ECB)
         ha = await base64_url_encode(
             master_key_cipher.encrypt(node_data['h'].encode("utf8") +
                                       node_data['h'].encode("utf8")))
@@ -608,7 +616,7 @@ class Mega:
         share_key_cipher = AES.new(share_key, AES.MODE_ECB)
         node_key = node_data['k']
         encrypted_node_key = await base64_url_encode(
-            share_key_cipher.encrypt(await a32_to_str(node_key)))
+            share_key_cipher.encrypt((await a32_to_str(node_key))))
 
         node_id = node_data['h']
         request_body = [{
@@ -636,7 +644,7 @@ class Mega:
         """
         Download a file by it's public url
         """
-        path = await self._parse_url(url).split('!')
+        path = (await self._parse_url(url)).split('!')
         file_id = path[0]
         file_key = path[1]
         return await self._download_file(
@@ -714,7 +722,7 @@ class Mega:
                                     mac_str.encode("utf8"))
             iv_str = await a32_to_str([iv[0], iv[1], iv[0], iv[1]])
 
-            for chunk_start, chunk_size in (await get_chunks(file_size)):
+            async for chunk_start, chunk_size in get_chunks(file_size):
                 chunk = input_file.read(chunk_size)
                 chunk = aes.decrypt(chunk)
                 temp_output_file.write(chunk)
@@ -758,7 +766,7 @@ class Mega:
         # request upload url, call 'u' method
         with open(filename, 'rb') as input_file:
             file_size = os.path.getsize(filename)
-            ul_url = await self._api_request({'a': 'u', 's': file_size})['p']
+            ul_url = (await self._api_request({'a': 'u', 's': file_size}))['p']
 
             # generate random aes key (128) for file
             ul_key = [random.randint(0, 0xFFFFFFFF) for _ in range(6)]
@@ -822,13 +830,13 @@ class Mega:
             attribs = {'n': dest_filename}
 
             encrypt_attribs = await base64_url_encode(
-                await encrypt_attr(attribs, ul_key[:4]))
+                (await encrypt_attr(attribs, ul_key[:4])))
             key = [
                 ul_key[0] ^ ul_key[4], ul_key[1] ^ ul_key[5],
                 ul_key[2] ^ meta_mac[0], ul_key[3] ^ meta_mac[1], ul_key[4],
                 ul_key[5], meta_mac[0], meta_mac[1]
             ]
-            encrypted_key = await a32_to_base64(await encrypt_key(key, self.master_key))
+            encrypted_key = await a32_to_base64((await encrypt_key(key, self.master_key)))
             logger.info('Sending request to update attributes')
             # update attributes
             data = await self._api_request({
@@ -854,8 +862,8 @@ class Mega:
 
         # encrypt attribs
         attribs = {'n': name}
-        encrypt_attribs = await base64_url_encode(await encrypt_attr(attribs, ul_key[:4]))
-        encrypted_key = await a32_to_base64(await encrypt_key(ul_key[:4], self.master_key))
+        encrypt_attribs = await base64_url_encode((await encrypt_attr(attribs, ul_key[:4])))
+        encrypted_key = await a32_to_base64((await encrypt_key(ul_key[:4], self.master_key)))
 
         # update attributes
         data = await self._api_request({
@@ -905,9 +913,9 @@ class Mega:
         # create new attribs
         attribs = {'n': new_name}
         # encrypt attribs
-        encrypt_attribs = await base64_url_encode(await encrypt_attr(attribs, file['k']))
-        encrypted_key = await a32_to_base64(await encrypt_key(file['key'],
-                                                  self.master_key))
+        encrypt_attribs = await base64_url_encode((await encrypt_attr(attribs, file['k'])))
+        encrypted_key = await a32_to_base64((await encrypt_key(file['key'],
+                                                  self.master_key)))
         # update attributes
         return await self._api_request([{
             'a': 'a',
@@ -939,7 +947,7 @@ class Mega:
 
         # determine target_node_id
         if type(target) == int:
-            target_node_id = str(await self.get_node_by_type(target)[0])
+            target_node_id = str((await self.get_node_by_type(target))[0])
         elif type(target) in (str, ):
             target_node_id = target
         else:
@@ -989,14 +997,14 @@ class Mega:
         """
         Get size and name from a public url, dict returned
         """
-        file_handle, file_key = await self._parse_url(url).split('!')
+        file_handle, file_key = (await self._parse_url(url)).split('!')
         return await self.get_public_file_info(file_handle, file_key)
 
     async def import_public_url(self, url, dest_node=None, dest_name=None):
         """
         Import the public url into user account
         """
-        file_handle, file_key = await self._parse_url(url).split('!')
+        file_handle, file_key = (await self._parse_url(url)).split('!')
         return await self.import_public_file(file_handle,
                                        file_key,
                                        dest_node=dest_node,
@@ -1018,7 +1026,7 @@ class Mega:
              key[3] ^ key[7])
 
         size = data['s']
-        unencrypted_attrs = await decrypt_attr(await base64_url_decode(data['at']), k)
+        unencrypted_attrs = await decrypt_attr((await base64_url_decode(data['at'])), k)
         if not unencrypted_attrs:
             return None
         result = {'size': size, 'name': unencrypted_attrs['n']}
@@ -1035,7 +1043,7 @@ class Mega:
         # Providing dest_node spare an API call to retrieve it.
         if dest_node is None:
             # Get '/Cloud Drive' folder no dest node specified
-            dest_node = await self.get_node_by_type(2)[1]
+            dest_node = (await self.get_node_by_type(2))[1]
 
         # Providing dest_name spares an API call to retrieve it.
         if dest_name is None:
@@ -1046,8 +1054,8 @@ class Mega:
         k = (key[0] ^ key[4], key[1] ^ key[5], key[2] ^ key[6],
              key[3] ^ key[7])
 
-        encrypted_key = await a32_to_base64(await encrypt_key(key, self.master_key))
-        encrypted_name = await base64_url_encode(await encrypt_attr({'n': dest_name}, k))
+        encrypted_key = await a32_to_base64((await encrypt_key(key, self.master_key)))
+        encrypted_name = await base64_url_encode((await encrypt_attr({'n': dest_name}, k)))
         return await self._api_request({
             'a':
             'p',
